/*
 *  OSStatusException.h
 *  finderrefreshd
 *
 *  Created by Chris Reed on 9/6/04.
 *  Copyright 2004 Manyetas. All rights reserved.
 *
 */

#include <Foundation/Foundation.h>

//! The name of the exception thrown by #ThrowIfOSStatus_.
extern NSString * OSStatusException;

//! \brief Throws an NSException if \a status is not equal to noErr.
//! The exception's name is OSStatusException and the user info dictionary has the
//! following keys:
//!		- "file": NSString of the path to the source file containing the code
//!				  the code that threw the exception.
//!		- "line": NSNumber of the line number of the code that threw the exception.
//!		- "status": NSNumber of the OSStatus value.
#define ThrowIfOSStatus_(status) do { \
		OSStatus _status_ = (status); \
		if (_status_ != noErr) @throw [NSException exceptionWithName:OSStatusException reason:[NSString stringWithFormat:@"%s returned %d (file: %s, line: %d)", #status, (int)_status_, __FILE__, __LINE__] userInfo:[NSDictionary dictionaryWithObjectsAndKeys:[NSNumber numberWithInt:(int)_status_], @"status", [NSString stringWithUTF8String:__FILE__], @"file", [NSNumber numberWithInt:__LINE__],	@"line", nil, nil]]; \
	} while (false)

